@@ -15,7 +15,6 @@ from oslo_config import cfg
 from oslo_utils import strutils
 
 from neutron_lib._i18n import _
-from neutron_lib.api import validators
 from neutron_lib import constants
 from neutron_lib import exceptions as n_exc
 from neutron_lib.utils import net as net_utils
@@ -256,7 +255,7 @@ def convert_to_protocol(data):
                       "names and their integer representation (0 to "
                       "255) are supported") % data
     try:
-        if validators.validate_range(convert_to_int(data), [0, 255]) is None:
+        if 0 <= convert_to_int(data) <= 255:
             return data
         else:
             raise n_exc.InvalidInput(error_message=error_message)
@@ -319,3 +318,17 @@ def convert_to_mac_if_none(data):
         return net_utils.get_random_mac(cfg.CONF.base_mac.split(':'))
 
     return data
+
+
+def convert_to_sanitized_mac_address(mac_address):
+    """Return a MAC address with format xx:xx:xx:xx:xx:xx
+
+    :param mac_address: The MAC address value
+    :return: A string with the MAC address formatted. If the MAC address
+             provided is invalid, the same input value is returned; the goal
+             of this method is not to validate it.
+    """
+    try:
+        return str(netaddr.EUI(mac_address, dialect=netaddr.mac_unix_expanded))
+    except netaddr.core.AddrFormatError:
+        return mac_address
