@@ -10,13 +10,21 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from neutron_lib.api.definitions import address_group
 from neutron_lib.api.definitions import address_scope
 from neutron_lib.api.definitions import agent
 from neutron_lib.api.definitions import agent_resources_synced
+from neutron_lib.api.definitions import agent_sort_key
 from neutron_lib.api.definitions import allowedaddresspairs
 from neutron_lib.api.definitions import auto_allocated_topology
 from neutron_lib.api.definitions import availability_zone
 from neutron_lib.api.definitions import availability_zone_filter
+from neutron_lib.api.definitions import bfd_for_extraroutes
+from neutron_lib.api.definitions import bfd_monitor
+from neutron_lib.api.definitions import bgp
+from neutron_lib.api.definitions import bgp_4byte_asn
+from neutron_lib.api.definitions import bgp_associations
+from neutron_lib.api.definitions import bgp_dragentscheduler
 from neutron_lib.api.definitions import bgpvpn
 from neutron_lib.api.definitions import bgpvpn_routes_control
 from neutron_lib.api.definitions import bgpvpn_stdattrs
@@ -28,8 +36,10 @@ from neutron_lib.api.definitions import data_plane_status
 from neutron_lib.api.definitions import default_subnetpools
 from neutron_lib.api.definitions import dhcpagentscheduler
 from neutron_lib.api.definitions import dns
+from neutron_lib.api.definitions import dns_domain_keywords
 from neutron_lib.api.definitions import dns_domain_ports
 from neutron_lib.api.definitions import dvr
+from neutron_lib.api.definitions import ecmp_routes
 from neutron_lib.api.definitions import empty_string_filtering
 from neutron_lib.api.definitions import expose_l3_conntrack_helper
 from neutron_lib.api.definitions import expose_port_forwarding_in_fip
@@ -40,6 +50,7 @@ from neutron_lib.api.definitions import extraroute_atomic
 from neutron_lib.api.definitions import filter_validation
 from neutron_lib.api.definitions import fip64
 from neutron_lib.api.definitions import fip_pf_description
+from neutron_lib.api.definitions import fip_pf_port_range
 from neutron_lib.api.definitions import fip_port_details
 from neutron_lib.api.definitions import firewall_v2
 from neutron_lib.api.definitions import flavors
@@ -54,11 +65,15 @@ from neutron_lib.api.definitions import l3
 from neutron_lib.api.definitions import l3_conntrack_helper
 from neutron_lib.api.definitions import l3_ext_gw_mode
 from neutron_lib.api.definitions import l3_ext_ha_mode
+from neutron_lib.api.definitions import l3_ext_ndp_proxy
 from neutron_lib.api.definitions import l3_flavors
+from neutron_lib.api.definitions import l3_multi_ext_gw
+from neutron_lib.api.definitions import l3_ndp_proxy
 from neutron_lib.api.definitions import l3_port_ip_change_not_allowed
 from neutron_lib.api.definitions import logging
 from neutron_lib.api.definitions import logging_resource
 from neutron_lib.api.definitions import metering
+from neutron_lib.api.definitions import metering_source_and_destination_filters
 from neutron_lib.api.definitions import multiprovidernet
 from neutron_lib.api.definitions import network
 from neutron_lib.api.definitions import network_availability_zone
@@ -68,8 +83,11 @@ from neutron_lib.api.definitions import network_mtu_writable
 from neutron_lib.api.definitions import network_segment_range
 from neutron_lib.api.definitions import pagination
 from neutron_lib.api.definitions import port
+from neutron_lib.api.definitions import port_device_profile
 from neutron_lib.api.definitions import port_mac_address_regenerate
+from neutron_lib.api.definitions import port_numa_affinity_policy
 from neutron_lib.api.definitions import port_resource_request
+from neutron_lib.api.definitions import port_resource_request_groups
 from neutron_lib.api.definitions import port_security
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import portbindings_extended
@@ -82,9 +100,13 @@ from neutron_lib.api.definitions import qos_bw_minimum_ingress
 from neutron_lib.api.definitions import qos_default
 from neutron_lib.api.definitions import qos_gateway_ip
 from neutron_lib.api.definitions import qos_port_network_policy
+from neutron_lib.api.definitions import qos_pps_minimum_rule
+from neutron_lib.api.definitions import qos_pps_rule
 from neutron_lib.api.definitions import qos_rule_type_details
 from neutron_lib.api.definitions import qos_rules_alias
+from neutron_lib.api.definitions import rbac_address_groups
 from neutron_lib.api.definitions import rbac_address_scope
+from neutron_lib.api.definitions import rbac_bgpvpn
 from neutron_lib.api.definitions import rbac_security_groups
 from neutron_lib.api.definitions import rbac_subnetpool
 from neutron_lib.api.definitions import revisionifmatch
@@ -92,7 +114,9 @@ from neutron_lib.api.definitions import router_admin_state_down_before_update
 from neutron_lib.api.definitions import router_availability_zone
 from neutron_lib.api.definitions import router_interface_fip
 from neutron_lib.api.definitions import routerservicetype
+from neutron_lib.api.definitions import security_groups_normalized_cidr
 from neutron_lib.api.definitions import security_groups_port_filtering
+from neutron_lib.api.definitions import security_groups_remote_address_group
 from neutron_lib.api.definitions import segment
 from neutron_lib.api.definitions import segments_peer_subnet_host_routes
 from neutron_lib.api.definitions import servicetype
@@ -120,13 +144,21 @@ from neutron_lib.api.definitions import vpn_flavors
 
 
 _ALL_API_DEFINITIONS = {
+    address_group,
     address_scope,
     agent,
     agent_resources_synced,
+    agent_sort_key,
     allowedaddresspairs,
     auto_allocated_topology,
     availability_zone,
     availability_zone_filter,
+    bfd_for_extraroutes,
+    bfd_monitor,
+    bgp,
+    bgp_4byte_asn,
+    bgp_associations,
+    bgp_dragentscheduler,
     bgpvpn,
     bgpvpn_routes_control,
     bgpvpn_stdattrs,
@@ -138,8 +170,10 @@ _ALL_API_DEFINITIONS = {
     default_subnetpools,
     dhcpagentscheduler,
     dns,
+    dns_domain_keywords,
     dns_domain_ports,
     dvr,
+    ecmp_routes,
     empty_string_filtering,
     expose_l3_conntrack_helper,
     expose_port_forwarding_in_fip,
@@ -153,6 +187,7 @@ _ALL_API_DEFINITIONS = {
     fip_port_details,
     flavors,
     floating_ip_port_forwarding,
+    fip_pf_port_range,
     fip_pf_description,
     floatingip_autodelete_internal,
     floatingip_pools,
@@ -164,11 +199,15 @@ _ALL_API_DEFINITIONS = {
     l3_conntrack_helper,
     l3_ext_gw_mode,
     l3_ext_ha_mode,
+    l3_ext_ndp_proxy,
     l3_flavors,
+    l3_multi_ext_gw,
+    l3_ndp_proxy,
     l3_port_ip_change_not_allowed,
     logging,
     logging_resource,
     metering,
+    metering_source_and_destination_filters,
     multiprovidernet,
     network,
     network_availability_zone,
@@ -178,8 +217,11 @@ _ALL_API_DEFINITIONS = {
     network_segment_range,
     pagination,
     port,
+    port_device_profile,
     port_mac_address_regenerate,
+    port_numa_affinity_policy,
     port_resource_request,
+    port_resource_request_groups,
     port_security,
     portbindings,
     portbindings_extended,
@@ -192,9 +234,13 @@ _ALL_API_DEFINITIONS = {
     qos_default,
     qos_gateway_ip,
     qos_port_network_policy,
+    qos_pps_minimum_rule,
+    qos_pps_rule,
     qos_rule_type_details,
     qos_rules_alias,
+    rbac_address_groups,
     rbac_address_scope,
+    rbac_bgpvpn,
     rbac_security_groups,
     rbac_subnetpool,
     revisionifmatch,
@@ -202,7 +248,9 @@ _ALL_API_DEFINITIONS = {
     router_availability_zone,
     router_interface_fip,
     routerservicetype,
+    security_groups_normalized_cidr,
     security_groups_port_filtering,
+    security_groups_remote_address_group,
     segment,
     segments_peer_subnet_host_routes,
     servicetype,
