@@ -25,6 +25,7 @@ from oslo_utils import uuidutils
 from webob import exc
 
 from neutron_lib._i18n import _
+from neutron_lib.api import converters
 from neutron_lib import constants
 from neutron_lib import exceptions as n_exc
 from neutron_lib.plugins import directory
@@ -586,7 +587,7 @@ def validate_hostroutes(data, valid_values=None):
     :param data: The data to validate. To be valid it must be a list like
         structure of host route dicts, each containing 'destination' and
         'nexthop' key values.
-    :param valid_values: Not used!
+    :param valid_values: A list of valid keys or None
     :returns: None if data is a valid list of unique host route dicts,
         otherwise a human readable message indicating why validation failed.
     """
@@ -595,9 +596,11 @@ def validate_hostroutes(data, valid_values=None):
         LOG.debug(msg)
         return msg
 
-    expected_keys = ['destination', 'nexthop']
     hostroutes = []
     for hostroute in data:
+        expected_keys = ['destination', 'nexthop']
+        if hostroute and 'bfd_monitor_id' in hostroute:
+            expected_keys.append('bfd_monitor_id')
         msg = _verify_dict_keys(expected_keys, hostroute)
         if msg:
             return msg
@@ -611,6 +614,10 @@ def validate_hostroutes(data, valid_values=None):
             msg = _("Duplicate hostroute '%s'") % hostroute
             LOG.debug(msg)
             return msg
+        if 'bfd_monitor_id' in hostroute:
+            msg = validate_uuid(hostroute['bfd_monitor_id'])
+            if msg:
+                return msg
         hostroutes.append(hostroute)
 
 
@@ -1169,6 +1176,35 @@ def validate_ethertype(ethertype, valid_values=None):
         return msg
 
 
+def validate_external_gw_info(data, valid_values=None):
+    """Validate data is an external_gateway_info.
+
+    :param data: The data to validate.
+    :param valid_values: Not used!
+    :returns: None if valid, error string otherwise.
+    """
+    return validate_dict_or_nodata(
+        data,
+        key_specs={
+            'network_id': {'type:uuid': None, 'required': True},
+            'external_fixed_ips': {'type:fixed_ips': None, 'required': False},
+            'enable_snat': {'type:boolean': None, 'required': False,
+                            'convert_to': converters.convert_to_boolean},
+        }
+    )
+
+
+def validate_external_gw_info_list(data, valid_values=None):
+    """Validate data is a list of external_gateway_info.
+
+    :param data: The data to validate.
+    :param valid_values: Not used!
+    :returns: None if valid, error string otherwise.
+    """
+    if data is not None:
+        return _validate_list_of_items(validate_external_gw_info, data)
+
+
 # Dictionary that maintains a list of validation functions
 validators = {'type:dict': validate_dict,
               'type:dict_or_none': validate_dict_or_none,
@@ -1215,7 +1251,9 @@ validators = {'type:dict': validate_dict,
               'type:service_plugin_type': validate_service_plugin_type,
               'type:list_of_subnets_or_none': validate_subnet_list_or_none,
               'type:list_of_subnet_service_types':
-                  validate_subnet_service_types
+                  validate_subnet_service_types,
+              'type:external_gw_info': validate_external_gw_info,
+              'type:external_gw_info_list': validate_external_gw_info_list,
               }
 
 
