@@ -11,6 +11,7 @@
 #    under the License.
 
 # String literals representing core resources.
+ADDRESS_GROUP = 'address_group'
 AGENT = 'agent'
 FLOATING_IP = 'floatingip'
 NETWORK = 'network'
@@ -32,3 +33,6 @@ SEGMENT_HOST_MAPPING = 'segment_host_mapping'
 SUBNET = 'subnet'
 SUBNETS = 'subnets'
 SUBNETPOOL_ADDRESS_SCOPE = 'subnetpool_address_scope'
+SUBPORTS = 'subports'
+TRUNK = 'trunk'
+TRUNK_PLUGIN = 'trunk_plugin'
