@@ -59,11 +59,15 @@ DEVICE_OWNER_AGENT_GW = (DEVICE_OWNER_NETWORK_PREFIX +
                          "floatingip_agent_gateway")
 DEVICE_OWNER_ROUTER_SNAT = (DEVICE_OWNER_NETWORK_PREFIX +
                             "router_centralized_snat")
+DEVICE_OWNER_ROUTED = (DEVICE_OWNER_NETWORK_PREFIX + "routed")
 # TODO(johnsom) Remove after these stop being used. Neutron-LBaaS is now
 #               retired (train) and these should no longer be necessary.
 DEVICE_OWNER_LOADBALANCER = DEVICE_OWNER_NEUTRON_PREFIX + "LOADBALANCER"
 DEVICE_OWNER_LOADBALANCERV2 = DEVICE_OWNER_NEUTRON_PREFIX + "LOADBALANCERV2"
 
+# Device owner for distributed services (e.g OVN Metadata/DHCP).
+DEVICE_OWNER_DISTRIBUTED = DEVICE_OWNER_NETWORK_PREFIX + "distributed"
+
 DEVICE_OWNER_PREFIXES = (DEVICE_OWNER_NETWORK_PREFIX,
                          DEVICE_OWNER_NEUTRON_PREFIX)
 
@@ -91,7 +95,8 @@ IP_VERSION_6 = 6
 IPv4_BITS = 32
 IPv6_BITS = 128
 
-INVALID_MAC_ADDRESSES = ['00:00:00:00:00:00', 'FF:FF:FF:FF:FF:FF']
+BROADCAST_MAC = 'FF:FF:FF:FF:FF:FF'
+INVALID_MAC_ADDRESSES = ['00:00:00:00:00:00', BROADCAST_MAC]
 
 IPv4_ANY = '0.0.0.0/0'
 IPv6_ANY = '::/0'
@@ -99,22 +104,34 @@ IP_ANY = {IP_VERSION_4: IPv4_ANY, IP_VERSION_6: IPv6_ANY}
 
 IPv6_LLA_PREFIX = 'fe80::/64'
 
-DHCP_CLIENT_PORT = 67
-DHCP_RESPONSE_PORT = 68
+DHCP_CLIENT_PORT = 68
+DHCP_RESPONSE_PORT = 67
 DHCPV6_CLIENT_PORT = 546
 DHCPV6_RESPONSE_PORT = 547
 
 FLOODING_ENTRY = ('00:00:00:00:00:00', '0.0.0.0')
 
+# Agent process name and description
+AGENT_PROCESS_DHCP = 'neutron-dhcp-agent'
+AGENT_PROCESS_L3 = 'neutron-l3-agent'
+AGENT_PROCESS_LINUXBRIDGE = 'neutron-linuxbridge-agent'
+AGENT_PROCESS_MACVTAP = 'neutron-macvtap-agent'
+AGENT_PROCESS_METADATA = 'neutron-metadata-agent'
+AGENT_PROCESS_METERING = 'neutron-metering-agent'
+AGENT_PROCESS_NIC_SWITCH = 'neutron-sriov-nic-agent'
+AGENT_PROCESS_OVN_METADATA = 'neutron-ovn-metadata-agent'
+AGENT_PROCESS_OVS = 'neutron-openvswitch-agent'
+
 AGENT_TYPE_DHCP = 'DHCP agent'
-AGENT_TYPE_OVS = 'Open vSwitch agent'
-AGENT_TYPE_LINUXBRIDGE = 'Linux bridge agent'
-AGENT_TYPE_OFA = 'OFA driver agent'
 AGENT_TYPE_L3 = 'L3 agent'
-AGENT_TYPE_METERING = 'Metering agent'
-AGENT_TYPE_METADATA = 'Metadata agent'
-AGENT_TYPE_NIC_SWITCH = 'NIC Switch agent'
+AGENT_TYPE_LINUXBRIDGE = 'Linux bridge agent'
 AGENT_TYPE_MACVTAP = 'Macvtap agent'
+AGENT_TYPE_METADATA = 'Metadata agent'
+AGENT_TYPE_METERING = 'Metering agent'
+AGENT_TYPE_NIC_SWITCH = 'NIC Switch agent'
+AGENT_TYPE_OFA = 'OFA driver agent'
+AGENT_TYPE_OVS = 'Open vSwitch agent'
+
 L2_AGENT_TOPIC = 'N/A'
 
 L3_AGENT_MODE_DVR = 'dvr'
@@ -307,6 +324,7 @@ NETWORK_SEGMENT_RANGE_TYPES = [TYPE_VLAN, TYPE_VXLAN, TYPE_GRE, TYPE_GENEVE]
 # For VLAN Network
 MIN_VLAN_TAG = 1
 MAX_VLAN_TAG = 4094
+VLAN_VALID_RANGE = (MIN_VLAN_TAG, MAX_VLAN_TAG)
 
 # For Geneve Tunnel
 MIN_GENEVE_VNI = 1
@@ -342,7 +360,10 @@ VALID_DSCP_MARKS = [0, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32, 34,
 
 INGRESS_DIRECTION = 'ingress'
 EGRESS_DIRECTION = 'egress'
+# Used only for QoS minimum guaranteed packet rate
+ANY_DIRECTION = 'any'
 VALID_DIRECTIONS = (INGRESS_DIRECTION, EGRESS_DIRECTION)
+VALID_DIRECTIONS_AND_ANY = (ANY_DIRECTION, *VALID_DIRECTIONS)
 
 PROVISIONAL_IPV6_PD_PREFIX = '::/64'
 
@@ -571,8 +592,6 @@ PORT_RANGE_MAX = 65535
 ETHERTYPE_MIN = 0
 ETHERTYPE_MAX = 65535
 
-DHCPV6_CLIENT_PORT = 546
-
 # Configuration values for accept_ra sysctl, copied from linux kernel
 # networking (netdev) tree, file Documentation/networking/ip-sysctl.txt
 #
@@ -593,7 +612,23 @@ ACCEPT_RA_WITH_FORWARDING = 2
 PRIVATE_CIDR_RANGE = '169.254.0.0/16'
 DVR_FIP_LL_CIDR = '169.254.64.0/18'
 L3_HA_NET_CIDR = '169.254.192.0/18'
-METADATA_CIDR = '169.254.169.254/32'
+
+# Well-known addresses of the metadata service.
+# When binding to an address, used with a port.
+METADATA_V4_IP = '169.254.169.254'
+# When configuring an address on an interface.
+# When adding a route.
+METADATA_V4_CIDR = '169.254.169.254/32'
+# When checking if a metadata subnet is present.
+METADATA_V4_SUBNET = '169.254.0.0/16'
+
+METADATA_V6_IP = 'fe80::a9fe:a9fe'
+METADATA_V6_CIDR = 'fe80::a9fe:a9fe/64'
+
+METADATA_PORT = 80
+
+# For backwards compatibility, prefer METADATA_V4_CIDR instead.
+METADATA_CIDR = METADATA_V4_CIDR
 
 # The only defined IpamAllocation status at this stage is 'ALLOCATED'.
 # More states will be available in the future - e.g.: RECYCLABLE
@@ -628,3 +663,235 @@ EXT_PARENT_PREFIX = 'ext_parent'
 
 RP_BANDWIDTHS = 'resource_provider_bandwidths'
 RP_INVENTORY_DEFAULTS = 'resource_provider_inventory_defaults'
+RP_PP_WITHOUT_DIRECTION = (
+    'resource_provider_packet_processing_without_direction')
+RP_PP_WITH_DIRECTION = 'resource_provider_packet_processing_with_direction'
+RP_PP_INVENTORY_DEFAULTS = (
+    'resource_provider_packet_processing_inventory_defaults')
+
+# Port NUMA affinity policies, matching Nova NUMA affinity policy constants
+PORT_NUMA_POLICY_REQUIRED = 'required'
+PORT_NUMA_POLICY_PREFERRED = 'preferred'
+PORT_NUMA_POLICY_LEGACY = 'legacy'
+PORT_NUMA_POLICIES = (PORT_NUMA_POLICY_REQUIRED, PORT_NUMA_POLICY_PREFERRED,
+                      PORT_NUMA_POLICY_LEGACY)
+
+# RBAC Sharing Actions
+ACCESS_SHARED = 'access_as_shared'
+ACCESS_READONLY = 'access_as_readonly'
+ACCESS_EXTERNAL = 'access_as_external'
+
+#######################
+# OVS related constants
+#######################
+
+# Special vlan_tci value indicating flat network
+FLAT_VLAN_TCI = '0x0000/0x1fff'
+
+# Topic for tunnel notifications between the plugin and agent
+TUNNEL = 'tunnel'
+
+# Name prefixes for veth device or patch port pair linking the integration
+# bridge with the physical bridge for a physical network
+PEER_INTEGRATION_PREFIX = 'int-'
+PEER_PHYSICAL_PREFIX = 'phy-'
+
+# Nonexistent peer used to create patch ports without associating them, it
+# allows to define flows before association
+NONEXISTENT_PEER = 'nonexistent-peer'
+
+# The different types of tunnels
+TUNNEL_NETWORK_TYPES = [TYPE_GRE, TYPE_VXLAN, TYPE_GENEVE]
+
+# --- OpenFlow table IDs
+
+# --- Integration bridge (int_br)
+
+LOCAL_SWITCHING = 0
+
+# The pyhsical network types of support DVR router
+DVR_PHYSICAL_NETWORK_TYPES = [TYPE_VLAN, TYPE_FLAT]
+
+# Various tables for DVR use of integration bridge flows
+DVR_TO_SRC_MAC = 1
+DVR_TO_SRC_MAC_PHYSICAL = 2
+ARP_DVR_MAC_TO_DST_MAC = 3
+ARP_DVR_MAC_TO_DST_MAC_PHYSICAL = 4
+CANARY_TABLE = 23
+
+# Table for ARP poison/spoofing prevention rules
+ARP_SPOOF_TABLE = 24
+
+# Table for MAC spoof filtering
+MAC_SPOOF_TABLE = 25
+
+# Table to decide whether further filtering is needed
+TRANSIENT_TABLE = 60
+LOCAL_MAC_DIRECT = 61
+TRANSIENT_EGRESS_TABLE = 62
+
+# Table for DHCP
+DHCP_IPV4_TABLE = 77
+DHCP_IPV6_TABLE = 78
+
+# Tables used for ovs firewall
+BASE_EGRESS_TABLE = 71
+RULES_EGRESS_TABLE = 72
+ACCEPT_OR_INGRESS_TABLE = 73
+BASE_INGRESS_TABLE = 81
+RULES_INGRESS_TABLE = 82
+
+OVS_FIREWALL_TABLES = (
+    BASE_EGRESS_TABLE,
+    RULES_EGRESS_TABLE,
+    ACCEPT_OR_INGRESS_TABLE,
+    BASE_INGRESS_TABLE,
+    RULES_INGRESS_TABLE,
+)
+
+# Tables for parties interacting with ovs firewall
+ACCEPTED_EGRESS_TRAFFIC_TABLE = 91
+ACCEPTED_INGRESS_TRAFFIC_TABLE = 92
+DROPPED_TRAFFIC_TABLE = 93
+ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE = 94
+
+INT_BR_ALL_TABLES = (
+    LOCAL_SWITCHING,
+    DVR_TO_SRC_MAC,
+    DVR_TO_SRC_MAC_PHYSICAL,
+    CANARY_TABLE,
+    ARP_SPOOF_TABLE,
+    MAC_SPOOF_TABLE,
+    LOCAL_MAC_DIRECT,
+    TRANSIENT_TABLE,
+    TRANSIENT_EGRESS_TABLE,
+    BASE_EGRESS_TABLE,
+    RULES_EGRESS_TABLE,
+    ACCEPT_OR_INGRESS_TABLE,
+    DHCP_IPV4_TABLE,
+    DHCP_IPV6_TABLE,
+    BASE_INGRESS_TABLE,
+    RULES_INGRESS_TABLE,
+    ACCEPTED_EGRESS_TRAFFIC_TABLE,
+    ACCEPTED_INGRESS_TRAFFIC_TABLE,
+    DROPPED_TRAFFIC_TABLE)
+
+# --- Tunnel bridge (tun_br)
+
+# Various tables for tunneling flows
+DVR_PROCESS = 1
+PATCH_LV_TO_TUN = 2
+GRE_TUN_TO_LV = 3
+VXLAN_TUN_TO_LV = 4
+GENEVE_TUN_TO_LV = 6
+
+DVR_NOT_LEARN = 9
+LEARN_FROM_TUN = 10
+UCAST_TO_TUN = 20
+ARP_RESPONDER = 21
+FLOOD_TO_TUN = 22
+# NOTE(vsaienko): transit table used by networking-bagpipe driver to
+# mirror traffic to EVPN and standard tunnels to gateway nodes
+BAGPIPE_FLOOD_TO_TUN_BROADCAST = 222
+
+TUN_BR_ALL_TABLES = (
+    LOCAL_SWITCHING,
+    DVR_PROCESS,
+    PATCH_LV_TO_TUN,
+    GRE_TUN_TO_LV,
+    VXLAN_TUN_TO_LV,
+    GENEVE_TUN_TO_LV,
+    DVR_NOT_LEARN,
+    LEARN_FROM_TUN,
+    UCAST_TO_TUN,
+    ARP_RESPONDER,
+    FLOOD_TO_TUN)
+
+# --- Physical Bridges (phys_brs)
+
+# Various tables for DVR use of physical bridge flows
+DVR_PROCESS_PHYSICAL = 1
+LOCAL_VLAN_TRANSLATION = 2
+DVR_NOT_LEARN_PHYSICAL = 3
+
+PHY_BR_ALL_TABLES = (
+    LOCAL_SWITCHING,
+    DVR_PROCESS_PHYSICAL,
+    LOCAL_VLAN_TRANSLATION,
+    DVR_NOT_LEARN_PHYSICAL)
+
+# --- end of OpenFlow table IDs
+
+# type for ARP reply in ARP header
+ARP_REPLY = '0x2'
+
+# Map tunnel types to tables number
+TUN_TABLE = {TYPE_GRE: GRE_TUN_TO_LV,
+             TYPE_VXLAN: VXLAN_TUN_TO_LV,
+             TYPE_GENEVE: GENEVE_TUN_TO_LV}
+
+
+# The default respawn interval for the ovsdb monitor
+DEFAULT_OVSDBMON_RESPAWN = 30
+
+# Represent invalid OF Port
+OFPORT_INVALID = -1
+
+ARP_RESPONDER_ACTIONS = ('move:NXM_OF_ETH_SRC[]->NXM_OF_ETH_DST[],'
+                         'mod_dl_src:%(mac)s,'
+                         'load:0x2->NXM_OF_ARP_OP[],'
+                         'move:NXM_NX_ARP_SHA[]->NXM_NX_ARP_THA[],'
+                         'move:NXM_OF_ARP_SPA[]->NXM_OF_ARP_TPA[],'
+                         'load:%(mac)#x->NXM_NX_ARP_SHA[],'
+                         'load:%(ip)#x->NXM_OF_ARP_SPA[],'
+                         'in_port')
+
+# Represent ovs status
+OVS_RESTARTED = 0
+OVS_NORMAL = 1
+OVS_DEAD = 2
+
+EXTENSION_DRIVER_TYPE = 'ovs'
+
+# ovs datapath types
+OVS_DATAPATH_SYSTEM = 'system'
+OVS_DATAPATH_NETDEV = 'netdev'
+OVS_DPDK_VHOST_USER = 'dpdkvhostuser'
+OVS_DPDK_VHOST_USER_CLIENT = 'dpdkvhostuserclient'
+
+OVS_DPDK_PORT_TYPES = [OVS_DPDK_VHOST_USER, OVS_DPDK_VHOST_USER_CLIENT]
+
+# default ovs vhost-user socket location
+VHOST_USER_SOCKET_DIR = '/var/run/openvswitch'
+
+MAX_DEVICE_RETRIES = 5
+
+# OpenFlow version constants
+OPENFLOW10 = "OpenFlow10"
+OPENFLOW11 = "OpenFlow11"
+OPENFLOW12 = "OpenFlow12"
+OPENFLOW13 = "OpenFlow13"
+OPENFLOW14 = "OpenFlow14"
+OPENFLOW15 = "OpenFlow15"
+
+OPENFLOW_MAX_PRIORITY = 65535
+
+# A placeholder for dead vlans.
+DEAD_VLAN_TAG = MAX_VLAN_TAG + 1
+
+# callback resource for setting 'bridge_name' in the 'binding:vif_details'
+OVS_BRIDGE_NAME = 'ovs_bridge_name'
+
+# callback resource for notifying to ovsdb handler
+OVSDB_RESOURCE = 'ovsdb'
+
+# Used in ovs port 'external_ids' in order mark it for no cleanup when
+# ovs_cleanup script is used.
+SKIP_CLEANUP = 'skip_cleanup'
+
+# neutron-dynamic-routing constants
+MIN_ASNUM = 1
+MAX_ASNUM = 65535
+MAX_4BYTE_ASNUM = 4294967295
+
+SUPPORTED_AUTH_TYPES = ['none', 'md5']
