@@ -16,9 +16,11 @@
 RULE_TYPE_BANDWIDTH_LIMIT = 'bandwidth_limit'
 RULE_TYPE_DSCP_MARKING = 'dscp_marking'
 RULE_TYPE_MINIMUM_BANDWIDTH = 'minimum_bandwidth'
+RULE_TYPE_PACKET_RATE_LIMIT = 'packet_rate_limit'
 VALID_RULE_TYPES = [RULE_TYPE_BANDWIDTH_LIMIT,
                     RULE_TYPE_DSCP_MARKING,
                     RULE_TYPE_MINIMUM_BANDWIDTH,
+                    RULE_TYPE_PACKET_RATE_LIMIT,
                     ]
 
 # Names of rules' attributes
@@ -28,6 +30,11 @@ MIN_KBPS = "min_kbps"
 DIRECTION = "direction"
 DSCP_MARK = "dscp_mark"
 
+# Names of pps rules' attributes
+MAX_KPPS = "max_kpps"
+MIN_KPPS = "min_kpps"
+MAX_BURST_KPPS = "max_burst_kpps"
+
 QOS_POLICY_ID = 'qos_policy_id'
 QOS_NETWORK_POLICY_ID = 'qos_network_policy_id'
 
