@@ -17,7 +17,7 @@
 
 import abc
 import contextlib
-import imp
+import importlib
 import inspect
 import os
 from os import path
@@ -1141,7 +1141,7 @@ class ModuleParser(object):
             if defined_name in sys.modules:
                 del sys.modules[defined_name]
             f, p, d = imp.find_module(module_name, search_paths)
-            module = imp.load_module(defined_name, f, p, d)
+            module = importlib.load_module(defined_name, f, p, d)
             if defined_name == '__init__':
                 setattr(module, '__path__', search_paths)
             return module
@@ -1194,11 +1194,11 @@ class ModuleParser(object):
                 elif inspect.isfunction(member):
                     self._notify(APISignature.SignatureType.FUNCTION,
                                  fqn, member,
-                                 arg_spec=inspect.getargspec(member))
+                                 arg_spec=inspect.getfullargspec(member))
                 elif inspect.ismethod(member):
                     self._notify(APISignature.SignatureType.METHOD,
                                  fqn, member,
-                                 arg_spec=inspect.getargspec(member))
+                                 arg_spec=inspect.getfullargspec(member))
                 else:
                     event = (APISignature.SignatureType.MODULE_ATTR
                              if inspect.ismodule(module)
